<?php if ( ! defined( 'ABSPATH' ) ) { die; }

add_filter('LaStudio/global_loop_variable', 'sebian_set_loop_variable');
if(!function_exists('sebian_set_loop_variable')){
    function sebian_set_loop_variable( $var = ''){
        return 'sebian_loop';
    }
}

add_filter('lastudio/google_map_api', 'sebian_add_googlemap_api');
if(!function_exists('sebian_add_googlemap_api')){
    function sebian_add_googlemap_api( $key = '' ){
        return Sebian()->settings->get('google_key', $key);
    }
}

add_filter('sebian/filter/page_title', 'sebian_override_page_title_bar_title');
if(!function_exists('sebian_override_page_title_bar_title')){
    function sebian_override_page_title_bar_title( $title ){

        $_tmp = '<header><div class="page-title h1">%s</div></header>';

        $context = (array) Sebian()->get_current_context();

        if(in_array('is_singular', $context)){
            $custom_title = Sebian()->settings->get_post_meta( get_queried_object_id(), 'page_title_custom');
            if(!empty( $custom_title) ){
                return sprintf($_tmp, $custom_title);
            }
        }

        if(in_array('is_tax', $context) || in_array('is_category', $context) || in_array('is_tag', $context)){
            $custom_title = Sebian()->settings->get_term_meta( get_queried_object_id(), 'page_title_custom');
            if(!empty( $custom_title) ){
                return sprintf($_tmp, $custom_title);
            }
        }

        return $title;
    }
}

add_action( 'pre_get_posts', 'sebian_set_posts_per_page_for_portfolio_cpt' );
if(!function_exists('sebian_set_posts_per_page_for_portfolio_cpt')){
    function sebian_set_posts_per_page_for_portfolio_cpt( $query ) {
        if ( !is_admin() && $query->is_main_query() ) {
            if( is_post_type_archive( 'la_portfolio' ) || is_tax(get_object_taxonomies( 'la_portfolio' ))){
                $pf_per_page = (int) Sebian()->settings->get('portfolio_per_page', 9);
                $query->set( 'posts_per_page', $pf_per_page );
            }
        }
    }
}


add_action('wp', 'sebian_hook_maintenance');
if(!function_exists('sebian_hook_maintenance')){
    function sebian_hook_maintenance(){
        wp_reset_postdata();
        $enable_private = Sebian()->settings->get('enable_maintenance', 'no');
        if(false && $enable_private == 'yes'){
            if(!is_user_logged_in()){
                $page_id = Sebian()->settings->get('maintenance_page');
                if(empty($page_id)){
                    wp_redirect(wp_login_url());
                    exit;
                }
                else{
                    $page_id = absint($page_id);
                    if(!is_page($page_id)){
                        wp_redirect(get_permalink($page_id));
                        exit;
                    }
                }
            }
        }
    }
}


add_action( 'wp_ajax_lastudio_ig_feed', 'sebian_ajax_get_ig_feed' );
add_action( 'wp_ajax_nopriv_lastudio_ig_feed', 'sebian_ajax_get_ig_feed' );

if(!function_exists('sebian_ajax_get_ig_feed')){
    function sebian_ajax_get_ig_feed(){
        // check token first;
        $token = Sebian()->settings->get('instagram_token', '');
        if(empty($token)){
            wp_send_json_error(['msg' => __('Invalid Token', 'sebian')]);
        }
        $life_time = get_transient('lastudio_ig_token');
        if(empty($life_time)){
            $ig_refresh_token_url = add_query_arg([
                'grant_type' => 'ig_refresh_token',
                'access_token' => $token
            ], 'https://graph.instagram.com/refresh_access_token');
            $response = wp_remote_get($ig_refresh_token_url);
            // request failed
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [1]', 'sebian')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [2]', 'sebian')]);
            }
            $body = wp_remote_retrieve_body($response);
            $body = json_decode($body, true);
            $expires_in = (int) $body['expires_in'] - DAY_IN_SECONDS;
            if($expires_in > 0){
                $token = $body['access_token'];
                $all_option = get_option(Sebian::get_option_name(), []);
                $all_option['instagram_token'] = $token;
                update_option(Sebian::get_option_name(), $all_option);
                set_transient('lastudio_ig_token', $body , $expires_in);
            }
            else{
                wp_send_json_error(['msg' => __('Token Expired [3]', 'sebian')]);
            }
        }

        $cache = get_transient('lastudio_ig_feed');
        if(empty($cache)){
            $ig_feed_url = add_query_arg([
                'fields'        => 'caption,media_type,media_url,thumbnail_url,permalink,timestamp',
                'access_token'  => $token,
                'limit'         => 20
            ], 'https://graph.instagram.com/me/media');

            $response = wp_remote_get($ig_feed_url);
            if ( is_wp_error( $response ) ) {
                wp_send_json_error(['msg' => __('Invalid Token [4]', 'sebian')]);
            }
            $code = (int) wp_remote_retrieve_response_code( $response );
            if ( $code !== 200 ) {
                wp_send_json_error(['msg' => __('Invalid Token [5]', 'sebian')]);
            }
            $data = wp_remote_retrieve_body($response);
            $data = json_decode($data, true);
            $cache = $data['data'];
            set_transient('lastudio_ig_feed', $cache, HOUR_IN_SECONDS * 12);
        }
        if(empty($cache)){
            wp_send_json_error(['msg' => __('Invalid Token [6]', 'sebian')]);
        }
        else{
            wp_send_json_success($cache);
        }
    }
}